OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Tiltott (örökölt jogosultság)",
    "Allowed (Inherited permission)" : "Engedélyezett (örökölt jogosultság)",
    "Denied" : "Tiltott",
    "Allowed" : "Engedélyezett",
    "Access denied" : "Hozzáférés megtagadva",
    "Access allowed" : "Hozzáférés engedélyezve",
    "Inherit permission" : "Jogosultság öröklése",
    "Deny" : "Megtagadás",
    "Allow" : "Engedélyezés",
    "Group" : "Csoport",
    "Team" : "Csapat",
    "Read" : "Olvasás",
    "Write" : "Írás",
    "Create" : "Létrehozás",
    "Delete" : "Törlés",
    "Share" : "Megosztás",
    "You" : "Ön",
    "Remove access rule" : "Hozzáférési szabály eltávolítása",
    "Select a user or group" : "Válasszon ki egy felhasználót vagy csoportot",
    "Permission denied. User does not have sufficient permissions." : "Engedély megtagadva. A felhasználó nem rendelkezik elegendő jogosultsággal.",
    "Unexpected status from server" : "Váratlan állapot a kiszolgálótól",
    "Add group" : "Csoport hozzáadása",
    "Default" : "Alapértelmezett",
    "Unlimited" : "Korlátlan",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Biztos, hogy törli a(z) „{folderName}” mappát a teljes tartalmával? Ez a művelet nem vonható vissza.",
    "Delete \"{folderName}\"?" : "Törli a következőt: „{folderName}”?",
    "Group or team" : "Csoport vagy csapat",
    "Folder name" : "Mappanév",
    "Quota" : "Kvóta",
    "Advanced Permissions" : "Speciális jogosultságok",
    "Previous" : "Előző",
    "Next" : "Következő",
    "User" : "Felhasználó",
    "Unknown" : "Ismeretlen",
    "Users/groups that can manage" : "Felhasználók/csoportok, akik kezelhetik",
    "None" : "Egyik sem",
    "No other groups or teams available" : "Nincs másik elérhető csoport vagy csapat",
    "No other groups available" : "Nincs másik elérhető csoport",
    "{displayName} (team)" : "{displayName} (csapat)",
    "Add group or team" : "Csoport vagy csapat hozzáadása",
    "{size} used" : "{size} felhasználva",
    "Unset" : "Kikapcsolás"
},
"nplurals=2; plural=(n != 1);");
